
import snmp.*;
import java.math.*;
import java.net.*;



public class SNMPSample
{

	
    public static void main(String args[]) 
    {

        try
        {

            // create a communications interface to a remote SNMP-capable device;
            // need to provide the remote host's InetAddress and the community
            // name for the device; in addition, need to  supply the version number
            // for the SNMP messages to be sent (the value 0 corresponding to SNMP
            // version 1)
            InetAddress hostAddress = InetAddress.getByName("1.1.1.1");
            String community = "public";
            int version = 0;    // SNMPv1
            
            SNMPv1CommunicationInterface comInterface = new SNMPv1CommunicationInterface(version, hostAddress, community);
            
            
            
            // now send an SNMP GET request to retrieve the value of the SNMP variable
            // corresponding to OID 1.3.6.1.2.1.2.1.0; this is the OID corresponding to
            // the device identifying string, and the type is thus SNMPOctetString
            String itemID = "1.3.6.1.2.1.1.1.0";
            
            System.out.println("Retrieving value corresponding to OID " + itemID);
            
            // the getMIBEntry method of the communications interface returns an SNMPVarBindList
            // object; this is essentially a Vector of SNMP (OID,value) pairs. In this case, the
            // returned Vector has just one pair inside it.
            SNMPVarBindList newVars = comInterface.getMIBEntry(itemID);
            
            // extract the (OID,value) pair from the SNMPVarBindList; the pair is just a two-element
            // SNMPSequence
            SNMPSequence pair = (SNMPSequence)(newVars.getSNMPObjectAt(0));
            
            // extract the object identifier from the pair; it's the first element in the sequence
            SNMPObjectIdentifier snmpOID = (SNMPObjectIdentifier)pair.getSNMPObjectAt(0);
            
            // extract the corresponding value from the pair; it's the second element in the sequence
            SNMPObject snmpValue = pair.getSNMPObjectAt(1);
            
            // print out the String representation of the retrieved value
            System.out.println("Retrieved value: type " + snmpValue.getClass().getName() + ", value " + snmpValue.toString());
            

            //BigInteger javaIntegerValue = (BigInteger)snmpValue.getValue();
            
            for(int p=0; p<1; ++p){
            	System.out.println("*********************************************************************");
                
                String bey;
                bey = "1.3.6.1.2.1.2.2.1.10";
                for(int o=0; o<5; ++o){
                	try {
                    	
                    	newVars = comInterface.getNextMIBEntry(bey);
                    	System.out.println(newVars.getValue() + " / " + newVars.hashCode() + " / " + newVars.toString());
                    	bey = newVars.getValue().toString().substring(3, 24);
                    	System.out.println(bey + " ");
                    	//newVars = comInterface.getMIBEntry(MyItemID);
    				} catch (Exception e) {
    					System.out.println("ERROR converting COM Interface - Proje");
    				}
                	
                    
                    // extract the (OID,value) pairs from the SNMPVarBindList; each pair is just a two-element
                    // SNMPSequence
                    for (int i = 0; i < newVars.size(); i++)
                    {
                    	try {
                    		pair = (SNMPSequence)(newVars.getSNMPObjectAt(i));
                    		
                    		// extract the object identifier from the pair; it's the first element in the sequence
                            snmpOID = (SNMPObjectIdentifier)pair.getSNMPObjectAt(0);
                            
    						// extract the corresponding value from the pair; it's the second element in the sequence
    	                    snmpValue = pair.getSNMPObjectAt(1);
    	                    
    	                    // print out the String representation of the retrieved value
    	                    System.out.println("Retrieved value: type " + snmpValue.getClass().getName() + ", value " + snmpValue.toString());
    					} catch (Exception e) {
    						System.out.println("ERROR in calculating MIB values - Proje");
    					}
                    }
                }
                System.out.println("*********************************************************************");
                Thread.sleep(3000);
            }
            
        }
        catch(Exception e)
        {
            System.out.println("Exception during SNMP operation:  " + e + "\n");
        }
        
    }

}